Merge "pgm-index: Move prolog utils to separate, deprecated, section"
diff --git a/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element.ts b/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element.ts
index e158bd7..db89823 100644
--- a/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element.ts
+++ b/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element.ts
@@ -40,6 +40,10 @@
 import {subscribe} from '../../../elements/lit/subscription-controller';
 import {GrDiffSection} from '../gr-diff-builder/gr-diff-section';
 import {repeat} from 'lit/directives/repeat.js';
+import {
+  Shortcut,
+  shortcutsServiceToken,
+} from '../../../services/shortcuts/shortcuts-service';
 
 const LARGE_DIFF_THRESHOLD_LINES = 10000;
 
@@ -78,6 +82,8 @@
 
   private getDiffModel = resolve(this, diffModelToken);
 
+  private readonly getShortcutsService = resolve(this, shortcutsServiceToken);
+
   /**
    * The browser API for handling selection does not (yet) work for selection
    * across multiple shadow DOM elements. So we are rendering gr-diff components
@@ -362,7 +368,12 @@
       <tbody class="binary-diff">
         <tr>
           <td colspan=${this.columnCount}>
-            <span>Difference in binary files</span>
+            <span
+              >Difference in binary files. Download commit to view (shortcut:
+              ${this.getShortcutsService().getShortcut(
+                Shortcut.OPEN_DOWNLOAD_DIALOG
+              )})</span
+            >
           </td>
         </tr>
       </tbody>
diff --git a/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element_test.ts b/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element_test.ts
index 1a43719..c793ee9 100644
--- a/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element_test.ts
+++ b/polygerrit-ui/app/embed/diff/gr-diff/gr-diff-element_test.ts
@@ -2804,7 +2804,9 @@
                 <tbody class="binary-diff">
                   <tr>
                     <td colspan="4">
-                      <span> Difference in binary files </span>
+                      <span>
+                        ${'Difference in binary files. Download commit to view (shortcut:\n              d)'}
+                      </span>
                     </td>
                   </tr>
                 </tbody>
@@ -3370,7 +3372,7 @@
       const body = queryAndAssert(element, 'tbody.binary-diff');
       assert.lightDom.equal(
         body,
         /* HTML */ '<span>Difference in binary files</span>'
       );
     });
   });
@@ -3370,7 +3372,7 @@
       assert.lightDom.equal(
         body,
-        /* HTML */ '<span>Difference in binary files</span>'
+        /* HTML */ '<span>Difference in binary files. Download commit to view (shortcut:\n              d)</span>'
       );
     });